@@ -8,37 +8,39 @@ var MazeModel = baseWigets.BaseModel.extend({
 	}),
 });
 
+const draw_beeper = function (layer, av, st, x, y, ts, val) {
+	let radius = 0.6 * ts;
+	let circle = new Konva.Circle({
+		radius: radius,
+		x: x,
+		y: y,
+		fill: "yellow",
+		stroke: "orange",
+		strokeWidth: 5,
+		name: `beeper-${av}-${st}-circle`,
+	});
+
+	let num = new Konva.Text({
+		text: val,
+		x: x - 5,
+		y: y - 7,
+		fontSize: 18,
+		name: `beeper-${av}-${st}-text`,
+	});
+	layer.add(circle, num);
+};
+
 const create_beepers = function (layer, beepers, left, bottom, ts) {
 	const cr2xy = function (col, row) {
 		return [left + ts * col, bottom - ts * row];
 	};
 
 	beepers.map(function (beeper) {
-		console.log("🚀 ~ file: konwa.html ~ line 156 ~ beeper", beeper);
-		let radius = 0.6 * ts;
 		let av = beeper.key[0];
 		let st = beeper.key[1];
 		const [x, y] = cr2xy(2 * av - 1, 2 * st - 1);
 		let val = beeper.value;
-
-		let circle = new Konva.Circle({
-			radius: radius,
-			x: x,
-			y: y,
-			fill: "yellow",
-			stroke: "orange",
-			strokeWidth: 5,
-			name: `beeper-${av}-${st}-circle`,
-		});
-
-		let num = new Konva.Text({
-			text: val,
-			x: x - 5,
-			y: y - 7,
-			fontSize: 18,
-			name: `beeper-${av}-${st}-text`,
-		});
-		layer.add(circle, num);
+		draw_beeper(layer, av, st, x, y, ts, val);
 	});
 };
 
@@ -242,11 +244,27 @@ var MazeView = baseWigets.BaseView.extend({
 		robot.clear_trace();
 	},
 
-	add_beeper: function () {},
+	add_beeper: function (av, st, x, y, val) {
+		draw_beeper(this.layer, av, st, x, y, this.ts, val);
+	},
 
-	update_beeper: function () {},
+	update_beeper: function (av, st, val) {
+		let text = this.layer.find(`.beeper-${av}-${st}-text`);
+		text.text(val);
+		this.layer.draw();
+	},
 
-	remove_beeper: function () {},
+	remove_beeper: function (av, st) {
+		let circle = this.layer.find(`.beeper-${av}-${st}-circle`);
+		let text = this.layer.find(`.beeper-${av}-${st}-text`);
+		if (circle) {
+			circle.destroy();
+		}
+		if (text) {
+			text.destroy();
+		}
+		this.layer.draw();
+	},
 
 	draw_grid: function (width, height, av, st, ts, walls, beepers) {
 		this.stage = new Konva.Stage({
