@@ -165,9 +165,7 @@ def _check_world(contents):
 
 
 def load_world(filename):
-    dir = os.path.dirname(__file__)
-    filename = os.path.join(dir, filename)
-    txt = open(os.path.abspath(filename), 'r').read()
+    txt = open(filename, 'r').read()
     txt = _re.sub('\r\n', '\n', str(txt))
     txt = _re.sub('\r', '\n', str(txt))
     _check_world(txt)
@@ -320,6 +318,7 @@ class Maze(Base):
         self.js_call('set_beeper_number', [beeper.av, beeper.st, beeper.number])
 
     def add_beeper(self, av, st):
+        x, y = self.cr2xy(2 * av - 1, 2 * st - 1)
         """Add a single beeper."""
         if (av, st) in self.beepers:
             self.beepers[(av, st)] += 1
@@ -329,17 +328,18 @@ class Maze(Base):
         else:
             self.beepers[(av, st)] = 1
             self._create_beeper(av, st)
-            self.js_call('add_beeper', [av, st, self.beepers[(av, st)]])
+            self.js_call('add_beeper', [av, st, x, y, self.beepers[(av, st)]])
 
     def remove_beeper(self, av, st):
         """Remove a beeper (does nothing if no beeper here)."""
+        x, y = self.cr2xy(2 * av - 1, 2 * st - 1)
         
         if (av, st) in self.beepers:
             self.beepers[(av, st)] -= 1
         if self.beepers[(av, st)] == 0:
             del self.beepers[(av, st)]
             del self.beeper_icons[(av,st)]
-            self.js_call('remove_beeper', [av, st, self.beepers[(av, st)]])
+            self.js_call('remove_beeper', [av, st])
         else:
             bp = self.beeper_icons[(av,st)]
             bp.set_number(self.beepers[(av, st)])
